@@ -1,44 +1,49 @@
-from nanpy.arduinoboard import (arduinoclassmethod, returns)
-
+from nanpy.arduinoboard import arduinoclassmethod, returns, FirmwareClass
 import time
 
-class Arduino():
 
-    HIGH = 1
-    LOW  = 0
-    INPUT  = 0
-    OUTPUT = 1
+class Arduino(FirmwareClass):
+    firmware_id = 'A'
+
+    LOW, HIGH = 0, 1
+    INPUT, OUTPUT = 0, 1
 
     @classmethod
-    @arduinoclassmethod
+    @arduinoclassmethod('dw')
     def digitalWrite(cls, pin, value):
         pass
 
     @classmethod
     @returns(int)
-    @arduinoclassmethod
+    @arduinoclassmethod('r')
     def digitalRead(cls, pin):
         pass
 
     @classmethod
-    @arduinoclassmethod
+    @arduinoclassmethod('aw')
     def analogWrite(cls, pin, value):
         pass
 
     @classmethod
     @returns(int)
-    @arduinoclassmethod
+    @arduinoclassmethod('a')
     def analogRead(cls, pin):
         pass
 
     @classmethod
-    @arduinoclassmethod
+    @arduinoclassmethod('pm')
     def pinMode(cls, pin, mode):
         pass
 
     @classmethod
     def delay(cls, value):
-        time.sleep(value/1000)
+        time.sleep(float(value)/1000)
+        
+    @classmethod
+    @returns(int)
+    @arduinoclassmethod('m')
+    def millis(cls):
+        pass
 
     @classmethod
     def map(cls, x, in_min, in_max, out_min, out_max):
