@@ -8,17 +8,27 @@ class DallasTemperature(ArduinoObject):
         self.pin = pin
         self.id = self.call('new', pin)
 
+    @arduinoobjectmethod
+    def setResolution(self, bits):
+        pass
+
+    @returns(int)
+    @arduinoobjectmethod
+    def getResolution(self, bits):
+        pass
+
     @returns(int)
     @arduinoobjectmethod
     def getDeviceCount(self):
         pass
 
+    @arduinoobjectmethod
     def getAddress(self, index):
         val = self.call('getAddress')
         if val == "1":
             return val
         return val.split(' ')
-            
+
 
     @arduinoobjectmethod
     def requestTemperatures(self, address = None):
